@@ -5,9 +5,8 @@ from . import logger_tools
 from . import thread_tools
 from . import func_tools
 
-__all__ = logger_tools.__all__ + thread_tools.__all__
+__all__ = logger_tools.__all__ + thread_tools.__all__ + func_tools.__all__
 
 
-__version__ = '0.0.2'
+__version__ = '0.0.6'
 __author__ = 'amiwrpremium'
-
